@@ -35,7 +35,7 @@ from swift.common.utils import get_logger, get_param, hash_path, public, \
     normalize_timestamp, split_path, storage_directory, TRUE_VALUES, \
     validate_device_partition
 from swift.common.constraints import ACCOUNT_LISTING_LIMIT, \
-    check_mount, check_float, check_utf8, FORMAT2CONTENT_TYPE
+    check_mount, check_float, check_utf8
 from swift.common.db_replicator import ReplicatorRpc
 from swift.common.http import HTTPInsufficientStorage
 
@@ -252,8 +252,11 @@ class AccountController(object):
             return HTTPBadRequest(body='parameters not utf8',
                                   content_type='text/plain', request=req)
         if query_format:
-            req.accept = FORMAT2CONTENT_TYPE.get(query_format.lower(),
-                                                 FORMAT2CONTENT_TYPE['plain'])
+            qfmt_lower = query_format.lower()
+            if qfmt_lower not in ['xml', 'json', 'plain']:
+                return HTTPBadRequest(body='format not supported',
+                                      content_type='text/plain', request=req)
+            req.accept = 'application/%s' % qfmt_lower
         try:
             out_content_type = req.accept.best_match(
                                     ['text/plain', 'application/json',
