@@ -35,9 +35,10 @@ from webob.exc import HTTPAccepted, HTTPBadRequest, HTTPCreated, \
 from xattr import getxattr, setxattr
 from eventlet import sleep, Timeout, tpool
 
-from swift.common.utils import mkdirs, normalize_timestamp, \
+from swift.common.utils import mkdirs, normalize_timestamp, public, \
     storage_directory, hash_path, renamer, fallocate, \
-    split_path, drop_buffer_cache, get_logger, write_pickle
+    split_path, drop_buffer_cache, get_logger, write_pickle, \
+    TRUE_VALUES, validate_device_partition
 from swift.common.bufferedhttp import http_connect
 from swift.common.constraints import check_object_creation, check_mount, \
     check_float, check_utf8
@@ -54,7 +55,6 @@ ASYNCDIR = 'async_pending'
 PICKLE_PROTOCOL = 2
 METADATA_KEY = 'user.swift.metadata'
 MAX_OBJECT_NAME_LENGTH = 1024
-KEEP_CACHE_SIZE = (5 * 1024 * 1024)
 # keep these lower-case
 DISALLOWED_HEADERS = set('content-length content-type deleted etag'.split())
 
@@ -104,12 +104,15 @@ class DiskFile(object):
     :param container: container name for the object
     :param obj: object name for the object
     :param keep_data_fp: if True, don't close the fp, otherwise close it
-    :param disk_chunk_Size: size of chunks on file reads
+    :param disk_chunk_size: size of chunks on file reads
+    :param iter_hook: called when __iter__ returns a chunk
     """
 
     def __init__(self, path, device, partition, account, container, obj,
-                 logger, keep_data_fp=False, disk_chunk_size=65536):
+                 logger, keep_data_fp=False, disk_chunk_size=65536,
+                 iter_hook=None):
         self.disk_chunk_size = disk_chunk_size
+        self.iter_hook = iter_hook
         self.name = '/' + '/'.join((account, container, obj))
         name_hash = hash_path(account, container, obj)
         self.datadir = os.path.join(path, device,
@@ -173,6 +176,8 @@ class DiskFile(object):
                             read - dropped_cache)
                         dropped_cache = read
                     yield chunk
+                    if self.iter_hook:
+                        self.iter_hook()
                 else:
                     self.read_to_eof = True
                     self.drop_cache(self.fp.fileno(), dropped_cache,
@@ -270,7 +275,7 @@ class DiskFile(object):
         :params fd: file descriptor of the temp file
         :param tmppath: path to the temporary file being used
         :param metadata: dictionary of metadata to be written
-        :param extention: extension to be used when making the file
+        :param extension: extension to be used when making the file
         """
         metadata['name'] = self.name
         timestamp = normalize_timestamp(metadata['X-Timestamp'])
@@ -356,11 +361,14 @@ class ObjectController(object):
         self.logger = get_logger(conf, log_route='object-server')
         self.devices = conf.get('devices', '/srv/node/')
         self.mount_check = conf.get('mount_check', 'true').lower() in \
-                              ('true', 't', '1', 'on', 'yes', 'y')
+            TRUE_VALUES
         self.node_timeout = int(conf.get('node_timeout', 3))
         self.conn_timeout = float(conf.get('conn_timeout', 0.5))
         self.disk_chunk_size = int(conf.get('disk_chunk_size', 65536))
         self.network_chunk_size = int(conf.get('network_chunk_size', 65536))
+        self.keep_cache_size = int(conf.get('keep_cache_size', 5242880))
+        self.keep_cache_private = \
+            conf.get('keep_cache_private', 'false').lower() in TRUE_VALUES
         self.log_requests = conf.get('log_requests', 't')[:1].lower() == 't'
         self.max_upload_time = int(conf.get('max_upload_time', 86400))
         self.slow = int(conf.get('slow', 0))
@@ -479,12 +487,14 @@ class ObjectController(object):
             '%s-%s/%s/%s' % (delete_at, account, container, obj),
             host, partition, contdevice, headers_out, objdevice)
 
+    @public
     def POST(self, request):
         """Handle HTTP POST requests for the Swift Object Server."""
         start_time = time.time()
         try:
             device, partition, account, container, obj = \
                 split_path(unquote(request.path), 5, 5, True)
+            validate_device_partition(device, partition)
         except ValueError, err:
             self.logger.increment('POST.errors')
             return HTTPBadRequest(body=str(err), request=request,
@@ -538,12 +548,14 @@ class ObjectController(object):
         self.logger.timing_since('POST.timing', start_time)
         return response_class(request=request)
 
+    @public
     def PUT(self, request):
         """Handle HTTP PUT requests for the Swift Object Server."""
         start_time = time.time()
         try:
             device, partition, account, container, obj = \
                 split_path(unquote(request.path), 5, 5, True)
+            validate_device_partition(device, partition)
         except ValueError, err:
             self.logger.increment('PUT.errors')
             return HTTPBadRequest(body=str(err), request=request,
@@ -590,6 +602,7 @@ class ObjectController(object):
                     tpool.execute(os.fdatasync, fd)
                     drop_buffer_cache(fd, last_sync, upload_size - last_sync)
                     last_sync = upload_size
+                sleep()
 
             if 'content-length' in request.headers and \
                     int(request.headers['content-length']) != upload_size:
@@ -635,12 +648,14 @@ class ObjectController(object):
         self.logger.timing_since('PUT.timing', start_time)
         return resp
 
+    @public
     def GET(self, request):
         """Handle HTTP GET requests for the Swift Object Server."""
         start_time = time.time()
         try:
             device, partition, account, container, obj = \
                 split_path(unquote(request.path), 5, 5, True)
+            validate_device_partition(device, partition)
         except ValueError, err:
             self.logger.increment('GET.errors')
             return HTTPBadRequest(body=str(err), request=request,
@@ -650,7 +665,8 @@ class ObjectController(object):
             return HTTPInsufficientStorage(drive=device, request=request)
         file = DiskFile(self.devices, device, partition, account, container,
                         obj, self.logger, keep_data_fp=True,
-                        disk_chunk_size=self.disk_chunk_size)
+                        disk_chunk_size=self.disk_chunk_size,
+                        iter_hook=sleep)
         if file.is_deleted() or ('X-Delete-At' in file.metadata and
                 int(file.metadata['X-Delete-At']) <= time.time()):
             if request.headers.get('if-match') == '*':
@@ -712,9 +728,10 @@ class ObjectController(object):
         response.etag = file.metadata['ETag']
         response.last_modified = float(file.metadata['X-Timestamp'])
         response.content_length = file_size
-        if response.content_length < KEEP_CACHE_SIZE and \
-                'X-Auth-Token' not in request.headers and \
-                'X-Storage-Token' not in request.headers:
+        if response.content_length < self.keep_cache_size and \
+                (self.keep_cache_private or
+                 ('X-Auth-Token' not in request.headers and
+                  'X-Storage-Token' not in request.headers)):
             file.keep_cache = True
         if 'Content-Encoding' in file.metadata:
             response.content_encoding = file.metadata['Content-Encoding']
@@ -722,12 +739,14 @@ class ObjectController(object):
         self.logger.timing_since('GET.timing', start_time)
         return request.get_response(response)
 
+    @public
     def HEAD(self, request):
         """Handle HTTP HEAD requests for the Swift Object Server."""
         start_time = time.time()
         try:
             device, partition, account, container, obj = \
                 split_path(unquote(request.path), 5, 5, True)
+            validate_device_partition(device, partition)
         except ValueError, err:
             self.logger.increment('HEAD.errors')
             resp = HTTPBadRequest(request=request)
@@ -767,12 +786,14 @@ class ObjectController(object):
         self.logger.timing_since('HEAD.timing', start_time)
         return response
 
+    @public
     def DELETE(self, request):
         """Handle HTTP DELETE requests for the Swift Object Server."""
         start_time = time.time()
         try:
             device, partition, account, container, obj = \
                 split_path(unquote(request.path), 5, 5, True)
+            validate_device_partition(device, partition)
         except ValueError, e:
             self.logger.increment('DELETE.errors')
             return HTTPBadRequest(body=str(e), request=request,
@@ -817,6 +838,7 @@ class ObjectController(object):
         self.logger.timing_since('DELETE.timing', start_time)
         return resp
 
+    @public
     def REPLICATE(self, request):
         """
         Handle REPLICATE requests for the Swift Object Server.  This is used
@@ -826,6 +848,7 @@ class ObjectController(object):
         try:
             device, partition, suffix = split_path(
                 unquote(request.path), 2, 3, True)
+            validate_device_partition(device, partition)
         except ValueError, e:
             self.logger.increment('REPLICATE.errors')
             return HTTPBadRequest(body=str(e), request=request,
@@ -851,14 +874,19 @@ class ObjectController(object):
         start_time = time.time()
         req = Request(env)
         self.logger.txn_id = req.headers.get('x-trans-id', None)
+
         if not check_utf8(req.path_info):
             res = HTTPPreconditionFailed(body='Invalid UTF8')
         else:
             try:
-                if hasattr(self, req.method):
-                    res = getattr(self, req.method)(req)
-                else:
+                # disallow methods which have not been marked 'public'
+                try:
+                    method = getattr(self, req.method)
+                    getattr(method, 'publicly_accessible')
+                except AttributeError:
                     res = HTTPMethodNotAllowed()
+                else:
+                    res = method(req)
             except (Exception, Timeout):
                 self.logger.exception(_('ERROR __call__ error with %(method)s'
                     ' %(path)s '), {'method': req.method, 'path': req.path})
