@@ -397,7 +397,13 @@ class Controller(object):
         attempts_left = len(nodes)
         path = '/%s' % account
         headers = {'x-trans-id': self.trans_id, 'Connection': 'close'}
-        for node in self.iter_nodes(partition, nodes, self.app.account_ring):
+        iternodes = self.iter_nodes(partition, nodes, self.app.account_ring)
+        while attempts_left > 0:
+            try:
+                node = iternodes.next()
+            except StopIteration:
+                break
+            attempts_left -= 1
             try:
                 with ConnectionTimeout(self.app.conn_timeout):
                     conn = http_connect(node['ip'], node['port'],
@@ -420,9 +426,6 @@ class Controller(object):
                         continue
                     else:
                         result_code = -1
-                        attempts_left -= 1
-                        if attempts_left <= 0:
-                            break
             except (Exception, Timeout):
                 self.exception_occurred(node, _('Account'),
                     _('Trying to get account info for %s') % path)
@@ -436,7 +439,9 @@ class Controller(object):
                 self.app.account_ring, partition, 'PUT',
                 path, [headers] * len(nodes))
             if not is_success(resp.status_int):
-                raise Exception('Could not autocreate account %r' % path)
+                self.app.logger.warning('Could not autocreate account %r' % \
+                                        path)
+                return None, None, None
             result_code = HTTP_OK
         if self.app.memcache and result_code in (HTTP_OK, HTTP_NOT_FOUND):
             if result_code == HTTP_OK:
@@ -489,7 +494,13 @@ class Controller(object):
         versions = None
         attempts_left = len(nodes)
         headers = {'x-trans-id': self.trans_id, 'Connection': 'close'}
-        for node in self.iter_nodes(partition, nodes, self.app.container_ring):
+        iternodes = self.iter_nodes(partition, nodes, self.app.container_ring)
+        while attempts_left > 0:
+            try:
+                node = iternodes.next()
+            except StopIteration:
+                break
+            attempts_left -= 1
             try:
                 with ConnectionTimeout(self.app.conn_timeout):
                     conn = http_connect(node['ip'], node['port'],
@@ -516,9 +527,6 @@ class Controller(object):
                         continue
                     else:
                         result_code = -1
-                        attempts_left -= 1
-                        if attempts_left <= 0:
-                            break
             except (Exception, Timeout):
                 self.exception_occurred(node, _('Container'),
                     _('Trying to get container info for %s') % path)
@@ -551,11 +559,21 @@ class Controller(object):
         for node in nodes:
             if not self.error_limited(node):
                 yield node
+        handoffs = 0
         for node in ring.get_more_nodes(partition):
             if not self.error_limited(node):
+                handoffs += 1
+                if self.app.log_handoffs:
+                    self.app.logger.increment('handoff_count')
+                    self.app.logger.warning(
+                        'Handoff requested (%d)' % handoffs)
+                    if handoffs == len(nodes):
+                        self.app.logger.increment('handoff_all_count')
                 yield node
 
-    def _make_request(self, nodes, part, method, path, headers, query):
+    def _make_request(self, nodes, part, method, path, headers, query,
+                      logger_thread_locals):
+        self.app.logger.thread_locals = logger_thread_locals
         for node in nodes:
             try:
                 with ConnectionTimeout(self.app.conn_timeout):
@@ -591,7 +609,7 @@ class Controller(object):
         pile = GreenPile(len(start_nodes))
         for head in headers:
             pile.spawn(self._make_request, nodes, part, method, path,
-                    head, query_string)
+                       head, query_string, self.app.logger.thread_locals)
         response = [resp for resp in pile if resp]
         while len(response) < len(start_nodes):
             response.append((HTTP_SERVICE_UNAVAILABLE, '', ''))
@@ -642,7 +660,7 @@ class Controller(object):
         """Handler for HTTP HEAD requests."""
         return self.GETorHEAD(req, stats_type='HEAD')
 
-    def _make_app_iter_reader(self, node, source, queue):
+    def _make_app_iter_reader(self, node, source, queue, logger_thread_locals):
         """
         Reads from the source and places data in the queue. It expects
         something else be reading from the queue and, if nothing does within
@@ -652,7 +670,12 @@ class Controller(object):
                      logging/error-limiting purposes.
         :param source: The httplib.Response object to read from.
         :param queue: The eventlet.queue.Queue to place read source data into.
+        :param logger_thread_locals: The thread local values to be set on the
+                                     self.app.logger to retain transaction
+                                     logging information.
         """
+        self.app.logger.thread_locals = logger_thread_locals
+        success = True
         try:
             try:
                 while True:
@@ -666,13 +689,15 @@ class Controller(object):
                     _('Client did not read from queue within %ss') %
                     self.app.client_timeout)
                 self.app.logger.increment('client_timeouts')
+                success = False
             except (Exception, Timeout):
                 self.exception_occurred(node, _('Object'),
                    _('Trying to read during GET'))
+                success = False
         finally:
-            # Ensure the queue getter gets an empty-string-terminator.
+            # Ensure the queue getter gets a terminator.
             queue.resize(2)
-            queue.put('')
+            queue.put(success)
             # Close-out the connection as best as possible.
             if getattr(source, 'swift_conn', None):
                 try:
@@ -708,11 +733,16 @@ class Controller(object):
                 # We then drop any reference to the source or node, for garbage
                 # collection purposes.
                 queue = Queue(1)
-                spawn_n(self._make_app_iter_reader, node, source, queue)
+                spawn_n(self._make_app_iter_reader, node, source, queue,
+                        self.app.logger.thread_locals)
                 source = node = None
                 while True:
                     chunk = queue.get(timeout=self.app.node_timeout)
-                    if not chunk:
+                    if isinstance(chunk, bool):  # terminator
+                        success = chunk
+                        if not success:
+                            raise Exception(_('Failed to read all data'
+                                              ' from the source'))
                         break
                     yield chunk
             except Empty:
@@ -743,8 +773,11 @@ class Controller(object):
         bodies = []
         source = None
         newest = req.headers.get('x-newest', 'f').lower() in TRUE_VALUES
-        for node in nodes:
-            if len(statuses) >= attempts:
+        nodes = iter(nodes)
+        while len(statuses) < attempts:
+            try:
+                node = nodes.next()
+            except StopIteration:
                 break
             if self.error_limited(node):
                 continue
@@ -788,6 +821,9 @@ class Controller(object):
                             source = possible_source
                     else:
                         source = possible_source
+                    statuses.append(source.status)
+                    reasons.append(source.reason)
+                    bodies.append('')
                     continue
                 else:
                     source = possible_source
@@ -1101,8 +1137,10 @@ class ObjectController(Controller):
                         _('Trying to write to %s') % path)
             conn.queue.task_done()
 
-    def _connect_put_node(self, nodes, part, path, headers):
+    def _connect_put_node(self, nodes, part, path, headers,
+                          logger_thread_locals):
         """Method for a file PUT connect"""
+        self.app.logger.thread_locals = logger_thread_locals
         for node in nodes:
             try:
                 with ConnectionTimeout(self.app.conn_timeout):
@@ -1312,7 +1350,7 @@ class ObjectController(Controller):
                 nheaders['X-Delete-At-Partition'] = delete_at_part
                 nheaders['X-Delete-At-Device'] = node['device']
             pile.spawn(self._connect_put_node, node_iter, partition,
-                        req.path_info, nheaders)
+                       req.path_info, nheaders, self.app.logger.thread_locals)
         conns = [conn for conn in pile if conn]
         if len(conns) <= len(nodes) / 2:
             self.app.logger.error(
@@ -1772,8 +1810,9 @@ class AccountController(Controller):
                 self.app.account_ring, partition, 'PUT',
                 '/' + self.account_name, [headers] * len(nodes))
             if not is_success(resp.status_int):
-                raise Exception('Could not autocreate account %r' %
-                                self.account_name)
+                self.app.logger.warning('Could not autocreate account %r' %
+                                        self.account_name)
+                return resp
             resp = self.GETorHEAD_base(req, _('Account'), partition, nodes,
                 req.path_info.rstrip('/'), len(nodes))
         self.app.logger.timing_since('%s.timing' % (stats_type,), start_time)
@@ -1840,8 +1879,9 @@ class AccountController(Controller):
                 self.app.account_ring, account_partition, 'PUT',
                 '/' + self.account_name, [headers] * len(accounts))
             if not is_success(resp.status_int):
-                raise Exception('Could not autocreate account %r' %
-                                self.account_name)
+                self.app.logger.warning('Could not autocreate account %r' %
+                                        self.account_name)
+                return resp
         self.app.logger.timing_since('POST.timing', start_time)
         return resp
 
@@ -1934,6 +1974,8 @@ class BaseApplication(object):
             int(conf.get('rate_limit_after_segment', 10))
         self.rate_limit_segments_per_sec = \
             int(conf.get('rate_limit_segments_per_sec', 1))
+        self.log_handoffs = \
+            conf.get('log_handoffs', 'true').lower() in TRUE_VALUES
 
     def get_controller(self, path):
         """
