@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2011 OpenStack, LLC.
+# Copyright (c) 2010-2012 OpenStack, LLC.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -201,7 +201,6 @@ class Connection(object):
 
         path = self.make_path(path, cfg=cfg)
         headers = self.make_headers(hdrs, cfg=cfg)
-
         if isinstance(parms, dict) and parms:
             quote = urllib.quote
             if cfg.get('no_quote') or cfg.get('no_parms_quote'):
@@ -209,7 +208,6 @@ class Connection(object):
             query_args = ['%s=%s' % (quote(x), quote(str(y))) for (x,y) in
                 parms.items()]
             path = '%s?%s' % (path, '&'.join(query_args))
-
         if not cfg.get('no_content_length'):
             if cfg.get('set_content_length'):
                 headers['Content-Length'] = cfg.get('set_content_length')
@@ -230,7 +228,7 @@ class Connection(object):
                 self.response = try_request()
             except httplib.HTTPException:
                 continue
-            
+
             if self.response.status == 401:
                 self.authenticate()
                 continue
@@ -244,7 +242,7 @@ class Connection(object):
         if self.response:
             return self.response.status
 
-        raise RequestError('Unable to compelte http request')
+        raise RequestError('Unable to complete http request')
 
     def put_start(self, path, hdrs={}, parms={}, cfg={}, chunked=False):
         self.http_connect()
@@ -296,7 +294,6 @@ class Base:
 
     def header_fields(self, fields):
         headers = dict(self.conn.response.getheaders())
-
         ret = {}
         for field in fields:
             if not headers.has_key(field[1]):
@@ -321,7 +318,7 @@ class Account(Base):
         format = parms.get('format', None)
         if format not in [None, 'json', 'xml']:
             raise RequestError('Invalid format: %s' % format)
-        if format == None and parms.has_key('format'):
+        if format is None and parms.has_key('format'):
             del parms['format']
 
         status = self.conn.make_request('GET', self.path, hdrs=hdrs,
@@ -410,7 +407,7 @@ class Container(Base):
         format = parms.get('format', None)
         if format not in [None, 'json', 'xml']:
             raise RequestError('Invalid format: %s' % format)
-        if format == None and parms.has_key('format'):
+        if format is None and parms.has_key('format'):
             del parms['format']
 
         status = self.conn.make_request('GET', self.path, hdrs=hdrs,
@@ -591,7 +588,7 @@ class File(Base):
 
     @classmethod
     def random_data(cls, size=None):
-        if size == None:
+        if size is None:
             size = random.randint(1, 32768)
         fd = open('/dev/urandom', 'r')
         data = fd.read(size)
@@ -674,9 +671,9 @@ class File(Base):
         return True
 
     def chunked_write(self, data=None, hdrs={}, parms={}, cfg={}):
-        if data != None and self.chunked_write_in_progress:
+        if data is not None and self.chunked_write_in_progress:
             self.conn.put_data(data, True)
-        elif data != None:
+        elif data is not None:
             self.chunked_write_in_progress = True
 
             headers = self.make_headers(cfg=cfg)
