@@ -1,5 +1,5 @@
 #!/usr/bin/python -u
-# Copyright (c) 2010-2011 OpenStack, LLC.
+# Copyright (c) 2010-2012 OpenStack, LLC.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,8 @@ from signal import SIGTERM
 from subprocess import Popen
 from time import sleep
 
-from swift.common import client, direct_client
+from swiftclient import client
+from swift.common import direct_client
 from test.probe.common import get_to_final_state, kill_pids, reset_environment
 
 
