@@ -1,5 +1,5 @@
 #!/usr/bin/python -u
-# Copyright (c) 2010-2011 OpenStack, LLC.
+# Copyright (c) 2010-2012 OpenStack, LLC.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,7 +21,8 @@ from subprocess import Popen
 from time import sleep
 from uuid import uuid4
 
-from swift.common import client, direct_client
+from swiftclient import client
+from swift.common import direct_client
 
 from test.probe.common import kill_pids, reset_environment
 
