@@ -3,7 +3,10 @@
 import sys
 import os
 import copy
+import logging
+from sys import exc_info
 from contextlib import contextmanager
+from collections import defaultdict
 from tempfile import NamedTemporaryFile
 from eventlet.green import socket
 from tempfile import mkdtemp
@@ -99,32 +102,50 @@ def temptree(files, contents=''):
         rmtree(tempdir)
 
 
-class FakeLogger(Handler):
+class NullLoggingHandler(logging.Handler):
+
+    def emit(self, record):
+        pass
+
+
+class FakeLogger(object):
     # a thread safe logger
 
     def __init__(self, *args, **kwargs):
-        self.log_dict = dict(error=[], info=[], warning=[], debug=[])
+        self._clear()
         self.level = logging.NOTSET
         if 'facility' in kwargs:
             self.facility = kwargs['facility']
 
-    def error(self, *args, **kwargs):
-        self.log_dict['error'].append((args, kwargs))
+    def _clear(self):
+        self.log_dict = defaultdict(list)
 
-    def info(self, *args, **kwargs):
-        self.log_dict['info'].append((args, kwargs))
+    def _store_in(store_name):
+        def stub_fn(self, *args, **kwargs):
+            self.log_dict[store_name].append((args, kwargs))
+        return stub_fn
 
-    def warning(self, *args, **kwargs):
-        self.log_dict['warning'].append((args, kwargs))
+    error = _store_in('error')
+    info = _store_in('info')
+    warning = _store_in('warning')
+    debug = _store_in('debug')
 
-    def debug(self, *args, **kwargs):
-        self.log_dict['debug'].append((args, kwargs))
+    def exception(self, *args, **kwargs):
+        self.log_dict['exception'].append((args, kwargs, str(exc_info()[1])))
+
+    # mock out the StatsD logging methods:
+    increment = _store_in('increment')
+    decrement = _store_in('decrement')
+    timing = _store_in('timing')
+    timing_since = _store_in('timing_since')
+    update_stats = _store_in('update_stats')
+    set_statsd_prefix = _store_in('set_statsd_prefix')
 
     def setFormatter(self, obj):
         self.formatter = obj
 
     def close(self):
-        self.log_dict = dict(error=[], info=[], warning=[], debug=[])
+        self._clear()
 
     def set_name(self, name):
         # don't touch _handlers
@@ -151,6 +172,7 @@ class FakeLogger(Handler):
     def handleError(self, record):
         pass
 
+
 original_syslog_handler = logging.handlers.SysLogHandler
 
 
