@@ -26,6 +26,18 @@ class FakeApp(object):
     def __init__(self, body=['FAKE APP']):
         self.body = body
 
+    def __call__(self, env, start_response):
+        start_response('200 OK', [('Content-Type', 'text/plain'),
+                            ('Content-Length', str(sum(map(len, self.body))))])
+        while env['wsgi.input'].read(5):
+            pass
+        return self.body
+
+
+class FakeAppNoContentLengthNoTransferEncoding(object):
+    def __init__(self, body=['FAKE APP']):
+        self.body = body
+
     def __call__(self, env, start_response):
         start_response('200 OK', [('Content-Type', 'text/plain')])
         while env['wsgi.input'].read(5):
@@ -46,7 +58,8 @@ class FileLikeExceptor(object):
 
 class FakeAppReadline(object):
     def __call__(self, env, start_response):
-        start_response('200 OK', [('Content-Type', 'text/plain')])
+        start_response('200 OK', [('Content-Type', 'text/plain'),
+                                 ('Content-Length', '8')])
         line = env['wsgi.input'].readline()
         return ["FAKE APP"]
 
@@ -224,5 +237,30 @@ class TestProxyLogging(unittest.TestCase):
         self.assertEquals(log_parts[6], '499')
         self.assertEquals(log_parts[10], '-')  # read length
 
+    def test_no_content_length_no_transfer_encoding(self):
+        app = proxy_logging.ProxyLoggingMiddleware(
+                FakeAppNoContentLengthNoTransferEncoding(), {})
+        app.access_logger = FakeLogger()
+        req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'})
+        resp = app(req.environ, start_response)
+        body = ''.join(resp)
+
+    def test_req_path_info_popping(self):
+        app = proxy_logging.ProxyLoggingMiddleware(FakeApp(), {})
+        app.access_logger = FakeLogger()
+        req = Request.blank('/v1/something', environ={'REQUEST_METHOD': 'GET'})
+        req.path_info_pop()
+        self.assertEquals(req.environ['PATH_INFO'], '/something')
+        resp = app(req.environ, start_response)
+        resp_body = ''.join(resp)
+        log_parts = app.access_logger.msg.split()
+        self.assertEquals(log_parts[3], 'GET')
+        self.assertEquals(log_parts[4], '/v1/something')
+        self.assertEquals(log_parts[5], 'HTTP/1.0')
+        self.assertEquals(log_parts[6], '200')
+        self.assertEquals(resp_body, 'FAKE APP')
+        self.assertEquals(log_parts[11], str(len(resp_body)))
+
+
 if __name__ == '__main__':
     unittest.main()
