@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2011 OpenStack, LLC.
+# Copyright (c) 2010-2012 OpenStack, LLC.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,12 +24,7 @@ import unittest
 from uuid import uuid4
 
 from swift.common import memcached
-
-
-class NullLoggingHandler(logging.Handler):
-
-    def emit(self, record):
-        pass
+from test.unit import NullLoggingHandler
 
 
 class ExplodingMockMemcached(object):
